@@ -16,7 +16,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 #{{{sub new
 sub new {
@@ -233,6 +233,30 @@ sub view_file {
 
 #}}}
 
+#{{{sub view_full_json
+sub view_full_json {
+    my ( $content, $remote_dest ) = @_;
+    if ( !defined $remote_dest ) {
+        croak 'No file to view specified!';
+    }
+    my $res = Apache::Sling::Request::request(
+        \$content,
+        Apache::Sling::ContentUtil::full_json_setup(
+            $content->{'BaseURL'}, $remote_dest
+        )
+    );
+    my $success = Apache::Sling::ContentUtil::full_json_eval($res);
+    my $message = (
+        $success
+        ? ${$res}->content
+        : "Problem viewing json: \"$remote_dest\""
+    );
+    $content->set_results( "$message", $res );
+    return $success;
+}
+
+#}}}
+
 1;
 
 __END__
@@ -291,6 +315,10 @@ View content details.
 
 View content.
 
+=head2 view_full_json
+
+View JSON representation of content.
+
 =head1 USAGE
 
 =head1 DESCRIPTION
